@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: CmdExec.cc,v 1.120 2006/04/19 09:48:02 lav Exp $ */
+/* $Id: CmdExec.cc,v 1.122 2006/05/24 07:30:21 lav Exp $ */
 
 #include <config.h>
 #include <errno.h>
@@ -934,7 +934,7 @@ char *CmdExec::MakePrompt()
 void CmdExec::beep_if_long()
 {
    if(start_time!=0 && long_running!=0
-   && now-start_time>long_running
+   && now.UnixTime()>start_time+long_running
    && interactive && Idle() && isatty(1))
       write(1,"\007",1);
 }
@@ -1233,7 +1233,7 @@ void CmdExec::RegisterCommand(const char *name,cmd_creator_t creator,const char
 {
    if(dyn_cmd_table==0)
    {
-      dyn_cmd_table_count=1;
+      dyn_cmd_table_count=2;
       for(const cmd_rec *c=static_cmd_table; c->name; c++)
 	 dyn_cmd_table_count++;
       dyn_cmd_table=(cmd_rec*)xmemdup(static_cmd_table,dyn_cmd_table_count*sizeof(cmd_rec));
