@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FileCopy.cc,v 1.121 2006/03/13 10:42:50 lav Exp $ */
+/* $Id: FileCopy.cc,v 1.125 2006/07/04 05:15:35 lav Exp $ */
 
 /* FileCopyPeer behaviour:
     1) when suspended, does nothing
@@ -89,10 +89,10 @@ int FileCopy::Do()
 	    goto pre_GET_INFO_WAIT;
 	 }
       }
+      if(get->GetSize()==NO_SIZE_YET)
+	 get->WantSize();
       if(get->GetSize()!=NO_SIZE && get->GetSize()!=NO_SIZE_YET)
 	 put->SetEntitySize(get->GetSize());
-      else if(get->GetSize()==NO_SIZE_YET)
-	 get->WantSize();
       if(get->GetDate()!=NO_DATE && get->GetDate()!=NO_DATE_YET)
 	 put->SetDate(get->GetDate());
       else if(get->GetDate()==NO_DATE_YET)
@@ -907,7 +907,7 @@ void FileCopyPeerFA::OpenSession()
       const char *b;
       int s;
       int err;
-      if(use_cache && LsCache::Find(session,file,FAmode,&err,&b,&s))
+      if(use_cache && FileAccess::cache->Find(session,file,FAmode,&err,&b,&s))
       {
 	 if(err)
 	 {
@@ -941,6 +941,7 @@ void FileCopyPeerFA::OpenSession()
    }
    session->Open(file,FAmode,seek_pos);
    session->SetFileURL(orig_url);
+   session->SetLimit(range_limit);
    if(mode==PUT)
    {
       if(try_time!=0)
@@ -970,6 +971,16 @@ void FileCopyPeerFA::OpenSession()
    }
 }
 
+void FileCopyPeerFA::WantSize()
+{
+   struct stat st;
+   if(!strcmp(session->GetProto(),"file")
+   && stat(dir_file(session->GetCwd(),file),&st)!=-1)
+      size=st.st_size;
+   else
+      super::WantSize();
+}
+
 void FileCopyPeerFA::RemoveFile()
 {
    session->Open(file,FA::REMOVE);
@@ -1085,7 +1096,7 @@ int FileCopyPeerFA::Get_LL(int len)
    if(res==0)
    {
       eof=true;
-      LsCache::Add(session,file,FAmode,FA::OK,this);
+      FileAccess::cache->Add(session,file,FAmode,FA::OK,this);
       SetSuggestedFileName(session->GetSuggestedFileName());
    }
    return res;
@@ -1183,7 +1194,7 @@ FileCopyPeerFA::FileCopyPeerFA(FileAccess *s,const char *f,int m)
    session=s;
    reuse_later=true;
    if(FAmode==FA::LIST || FAmode==FA::LONG_LIST)
-      Save(LsCache::SizeLimit());
+      Save(FileAccess::cache->SizeLimit());
 }
 FileCopyPeerFA::~FileCopyPeerFA()
 {
@@ -1257,7 +1268,7 @@ FileCopyPeerFDStream::FileCopyPeerFDStream(FDStream *o,dir_t m)
       write_allowed=false;
    put_ll_timer=0;
    if(m==PUT)
-      put_ll_timer=new Timer(TimeDiff(0,200));
+      put_ll_timer=new Timer(0,200);
    verify=0;
 }
 FileCopyPeerFDStream::~FileCopyPeerFDStream()
@@ -1663,6 +1674,22 @@ FgData *FileCopyPeerFDStream::GetFgData(bool fg)
    return 0;
 }
 
+void FileCopyPeerFDStream::WantSize()
+{
+   struct stat st;
+   st.st_size=NO_SIZE;
+
+   if(stream->fd!=-1)
+      fstat(stream->fd,&st);
+   else if(stream->full_name)
+      stat(stream->full_name,&st);
+
+   if(st.st_size!=NO_SIZE)
+      size=st.st_size;
+   else
+      super::WantSize();
+}
+
 void FileCopyPeerFDStream::RemoveFile()
 {
    stream->remove();
