@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: MirrorJob.cc,v 1.133 2006/04/19 09:48:04 lav Exp $ */
+/* $Id: MirrorJob.cc,v 1.134 2006/06/30 14:10:28 lav Exp $ */
 
 #include <config.h>
 
@@ -311,7 +311,7 @@ void  MirrorJob::HandleFile(FileInfo *file)
 	    ArgV *get_args=new ArgV("mirror");
 	    get_args->Append(file->name);
 	    get_args->Append(dir_file(target_dir,file->name));
-	    pgetJob *cp=new pgetJob(source_session->Clone(),get_args);
+	    pgetJob *cp=new pgetJob(source_session->Clone(),get_args,cont_this);
 	    cp->SetMaxConn(pget_n);
 	    if(remove_source_files)
 	       cp->RemoveSourceLater();
