@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: StatusLine.cc,v 1.34 2006/02/06 11:04:00 lav Exp $ */
+/* $Id: StatusLine.cc,v 1.35 2006/06/19 06:08:31 lav Exp $ */
 
 #include <config.h>
 #include <sys/types.h>
@@ -193,6 +193,8 @@ void StatusLine::update(const char *const *newstr,int newstr_height)
 
    // clear old extra lines. Assume we are at beginning of last shown line.
    int j=shown.Count();
+   if(!prev_line)    // if there is no way to go up, show a single line only.
+      j=newstr_height=1;
    int i=j-newstr_height;
    char *spaces=string_alloca(w+1);
    memset(spaces,' ',w);
