@@ -1,7 +1,7 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1996-2002 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2006 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: complete.cc,v 1.70 2004/11/03 08:37:44 lav Exp $ */
+/* $Id: complete.cc,v 1.72 2006/02/06 10:57:30 lav Exp $ */
 
 #include <config.h>
 
@@ -660,7 +660,7 @@ static char **lftp_completion (const char *text,int start,int end)
 	    type=REMOTE_DIR;
 	 goto really_remote;
       }
-
+   really_local:
       ArgV arg("", ResMgr::Query("cmd:cls-completion-default", 0));
       fso.parse_argv(&arg);
 
@@ -729,7 +729,11 @@ static char **lftp_completion (const char *text,int start,int end)
    case REMOTE_FILE:
    case REMOTE_DIR: {
       if(!remote_completion && !force_remote)
-	 break; // local
+      {
+	 if(type==REMOTE_DIR)
+	    type=LOCAL_DIR;
+	 goto really_local;
+      }
    really_remote:
       if(!strncmp(text,"bm:",3) && !strchr(text,'/'))
       {
