@@ -1,7 +1,7 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1996-2002 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2005 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: misc.cc,v 1.73 2005/06/21 12:17:21 lav Exp $ */
+/* $Id: misc.cc,v 1.81 2006/02/06 11:00:41 lav Exp $ */
 
 #include <config.h>
 #include "xmalloc.h"
@@ -441,7 +441,7 @@ int guess_year(int month,int day,int hour,int minute)
    const struct tm &now=SMTask::now;
    int year=now.tm_year+1900;
    if(month     *32+        day
-    > now.tm_mon*32+now.tm_mday+1)
+    > now.tm_mon*32+now.tm_mday+6)
       year--;
    return year;
 }
@@ -459,8 +459,9 @@ const char *squeeze_file_name(const char *name,int w)
    static int buf_len;
    int mbflags=MBSW_ACCEPT_INVALID|MBSW_ACCEPT_UNPRINTABLE;
 
-   int name_width=mbswidth(name,mbflags);
+   name=url::remove_password(name);
 
+   int name_width=mbswidth(name,mbflags);
    if(name_width<=w)
       return name;
 
@@ -638,7 +639,8 @@ char *Subst(const char *txt, const subst_t *s)
 	    unsigned len;
 	    unsigned code;
 	    txt--;
-	    sscanf(txt,"%3o%n",&code,&len);
+	    if(sscanf(txt,"%3o%n",&code,&len)!=1)
+	       continue; // should never happen.
 	    ch=code;
 	    txt+=len;
 	    str[0]=ch;
@@ -910,3 +912,42 @@ bool temporary_network_error(int err)
    }
    return false;
 }
+
+const char *get_lftp_home()
+{
+   static char *home=NULL;
+
+   if(home)
+      return home;
+
+   home=getenv("LFTP_HOME");
+   if(!home)
+   {
+      home=getenv("HOME");
+      if(home)
+      {
+         char *tmp=(char*)malloc(strlen(home)+6+1);
+         sprintf(tmp,"%s/.lftp",home);
+         home=tmp;
+      }
+      else
+         return NULL;
+   }
+   else
+      home=xstrdup(home);
+
+   if(!*home)
+      return NULL;
+
+   mkdir(home,0755);
+   return home;
+}
+
+const char *memrchr(const char *buf,char c,size_t len)
+{
+   buf+=len;
+   while(len-->0)
+      if(*--buf==c)
+	 return buf;
+   return 0;
+}
